@@ -13,7 +13,7 @@ use Carp qw( croak );
 use File::Temp ();
 
 # ABSTRACT: Interface to open3 under AnyEvent
-our $VERSION = '0.82'; # VERSION
+our $VERSION = '0.83'; # VERSION
 
 
 sub new
@@ -22,16 +22,12 @@ sub new
   my $class = shift;
   my $args = (reftype($_[0]) || '') eq 'HASH' ? shift : { @_ };
   my %self;
+  croak "stdin passed into AnyEvent::Open3::Simple->new no longer supported" if $args->{stdin};
+  croak "raw passed into AnyEvent::Open::Simple->new no longer supported" if $args->{raw};
   $self{$_} = $args->{$_} || $default_handler for qw( on_stdout on_stderr on_start on_exit on_signal on_fail on_error on_success );
-  if($args->{stdin})
-  {
-    warnings::warnif('deprecated', "passing stdin to the constructor of AnyEvent::Open3::Simple is deprecated");
-    $self{stdin} = ref $args->{stdin} ? $args->{stdin} : \$args->{stdin};
-  }
   $self{impl} = $args->{implementation} 
              || $ENV{ANYEVENT_OPEN3_SIMPLE}
              || ($^O eq 'MSWin32' ? 'idle' : 'child');
-  $self{raw} = $args->{raw} || 0;
   croak "unknown implementation $self{impl}" unless $self{impl} =~ /^(idle|child)$/;
   bless \%self, $class;
 }
@@ -44,7 +40,7 @@ sub run
 
   my $proc_user = (ref $_[-1] eq 'CODE' ? pop : sub {});
 
-  my $stdin = $_[0]->{stdin};
+  my $stdin;
   $stdin = pop if ref $_[-1];
 
   my($self, $program, @arguments) = @_;
@@ -83,64 +79,29 @@ sub run
   my $watcher_stdout;
   my $watcher_stderr;
 
-  if($self->{raw})
-  {
+  $watcher_stdout = AnyEvent->io(
+    fh   => $child_stdout,
+    poll => 'r',
+    cb   => sub {
+      my $input = <$child_stdout>;
+      return unless defined $input;
+      $input =~ s/(\015?\012|\015)$//;
+      my $ref = $self->{on_stdout};
+      ref($ref) eq 'ARRAY' ? push @$ref, $input : $ref->($proc, $input);
+    },
+  );
 
-    require AnyEvent::Handle;
-    $watcher_stdout = AnyEvent::Handle->new(
-      fh => $child_stdout,
-      on_error => sub {
-        $self->{on_stdout}->($proc,$_[0]{rbuf});
-      },
-    );
-    $watcher_stdout->on_read(sub {
-      $watcher_stdout->push_read(sub {
-        $DB::single = 1;
-        $self->{on_stdout}->($proc,$_[0]{rbuf});
-        $_[0]{rbuf} = '';
-      });
-    });
-    $watcher_stderr = AnyEvent::Handle->new(
-      fh => $child_stderr,
-      on_error => sub {
-        $self->{on_stderr}->($proc,$_[0]{rbuf});
-      },
-    );
-    $watcher_stderr->on_read(sub {
-      $watcher_stdout->push_read(sub {
-        $self->{on_stderr}->($proc,$_[0]{rbuf});
-        $_[0]{rbuf} = '';
-      });
-    });
-
-  }
-  else
-  {
-
-    $watcher_stdout = AnyEvent->io(
-      fh   => $child_stdout,
-      poll => 'r',
-      cb   => sub {
-        my $input = <$child_stdout>;
-        return unless defined $input;
-        $input =~ s/(\015?\012|\015)$//;
-        my $ref = $self->{on_stdout};
-        ref($ref) eq 'ARRAY' ? push @$ref, $input : $ref->($proc, $input);
-      },
-    );
-
-    $watcher_stderr = AnyEvent->io(
-      fh   => $child_stderr,
-      poll => 'r',
-      cb   => sub {
-        my $input = <$child_stderr>;
-        return unless defined $input;
-        $input =~ s/(\015?\012|\015)$//;
-        my $ref = $self->{on_stderr};
-        ref($ref) eq 'ARRAY' ? push @$ref, $input : $ref->($proc, $input);
-      },
-    );
-  }
+  $watcher_stderr = AnyEvent->io(
+    fh   => $child_stderr,
+    poll => 'r',
+    cb   => sub {
+      my $input = <$child_stderr>;
+      return unless defined $input;
+      $input =~ s/(\015?\012|\015)$//;
+      my $ref = $self->{on_stderr};
+      ref($ref) eq 'ARRAY' ? push @$ref, $input : $ref->($proc, $input);
+    },
+  );
 
   my $watcher_child;
 
@@ -227,7 +188,7 @@ AnyEvent::Open3::Simple - Interface to open3 under AnyEvent
 
 =head1 VERSION
 
-version 0.82
+version 0.83
 
 =head1 SYNOPSIS
 
@@ -307,12 +268,6 @@ environment variable, like this:
 
  % export ANYEVENT_OPEN3_SIMPLE=idle
 
-=item * stdin (DEPRECATED)
-
-Deprecated attribute for passing the entire content of stdin to the subprocess.
-This attribute may be removed from a future version of L<AnyEvent::Open3::Simple>
-(but not before 18 March 2015).  Instead use one of
-
 =over 4
 
 =item L<AnyEvent::Open3::Simple::Process#print>
