@@ -5,7 +5,7 @@ use warnings;
 use 5.006;
 
 # ABSTRACT: Process run using AnyEvent::Open3::Simple
-our $VERSION = '0.82'; # VERSION
+our $VERSION = '0.83'; # VERSION
 
 
 sub new
@@ -64,7 +64,7 @@ AnyEvent::Open3::Simple::Process - Process run using AnyEvent::Open3::Simple
 
 =head1 VERSION
 
-version 0.82
+version 0.83
 
 =head1 DESCRIPTION
 
@@ -86,28 +86,25 @@ Return the Process ID of the child process.
 
 Write to the subprocess' stdin.
 
-Be careful to use either the C<stdin> attribute on the L<AnyEvent::Open::Simple>
-object or this C<print> methods for a given instance of L<AnyEvent::Open3::Simple>,
-but not both!  Otherwise bad things may happen.
+Do NOT use this method if you have passed stdin via the C<$stdin> argument
+on the L<AnyEvent::Open3::Simple#run> method.
 
 Currently on (non cygwin) Windows (Strawberry, ActiveState) this method is not
-supported, so if you need to send (standard) input to the subprocess, use the
-C<stdin> attribute on the L<AnyEvent::Open::Simple> constructor.
+supported, so if you need to send (standard) input to the subprocess, you must pass
+it into the L<AnyEvent::Open3::Simple#run> method.
 
 =head2 say
 
  $proc->say(@data);
 
-Write to the subprocess' stdin, adding a new line at the end.  This functionality
-is unsupported on Microsoft Windows.
+Write to the subprocess' stdin, adding a new line at the end.
 
-Be careful to use either the C<stdin> attribute on the L<AnyEvent::Open::Simple>
-object or this C<say> methods for a given instance of L<AnyEvent::Open3::Simple>,
-but not both!  Otherwise bad things may happen.
+Do NOT use this method if you have passed stdin via the C<$stdin> argument
+on the L<AnyEvent::Open3::Simple#run> method.
 
 Currently on (non cygwin) Windows (Strawberry, ActiveState) this method is not
-supported, so if you need to send (standard) input to the subprocess, use the
-C<stdin> attribute on the L<AnyEvent::Open::Simple> constructor.
+supported, so if you need to send (standard) input to the subprocess, you must pass
+it into the L<AnyEvent::Open3::Simple#run> method.
 
 =head2 close
 
@@ -129,11 +126,12 @@ between callbacks, for example:
  AnyEvent::Open3::Simple->new(
    on_start => sub {
      my($proc) = @_;
-     $proc->user({ message => 'hello there' });
+     $proc->user({ prefix => '> ' });
    },
    on_stdout => sub {
-     my($proc) = @_;
-     say $proc->user->{message};
+     my($proc, $line) = @_;
+     my $prefix = $proc->user->{prefix};
+     say "$prefix$line";
    },
  );
 
